==> mingw-w64-clang-aarch64-qt6-declarative-static-6.9.1-1-any.pkg.tar.zst: usr/aarch64-w64-mingw32/static/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtquickcontrols2fluentwinui3stylepluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/libqtquickcontrols2fluentwinui3styleplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/libqtquickcontrols2fluentwinui3styleplugin.a" )

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_Controls_FluentWinUI3_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_Controls_FluentWinUI3_init.cpp.obj" )

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2fluentwinui3styleplugin_raw_qml_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2fluentwinui3styleplugin_raw_qml_0_init.cpp.obj" )

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_init/qtquickcontrols2fluentwinui3styleplugin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin_init "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_init/qtquickcontrols2fluentwinui3styleplugin_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-declarative-static-6.10.2-1-any.pkg.tar.zst: usr/aarch64-w64-mingw32/static/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtquickcontrols2fluentwinui3stylepluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/libqtquickcontrols2fluentwinui3styleplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/libqtquickcontrols2fluentwinui3styleplugin.a" )

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_Controls_FluentWinUI3_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_Controls_FluentWinUI3_init.cpp.obj" )

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2fluentwinui3styleplugin_raw_qml_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_2 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2fluentwinui3styleplugin_raw_qml_0_init.cpp.obj" )

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_3" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_3/.qt/rcc/qrc_qtquickcontrols2fluentwinui3styleplugin_raw_res_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin_resources_3 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_resources_3/.qt/rcc/qrc_qtquickcontrols2fluentwinui3styleplugin_raw_res_0_init.cpp.obj" )

# Import target "Qt6::qtquickcontrols2fluentwinui3styleplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2fluentwinui3styleplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2fluentwinui3styleplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_init/qtquickcontrols2fluentwinui3styleplugin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2fluentwinui3styleplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2fluentwinui3styleplugin_init "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/Controls/FluentWinUI3/objects-Release/qtquickcontrols2fluentwinui3styleplugin_init/qtquickcontrols2fluentwinui3styleplugin_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
